@@ -265,6 +265,37 @@ typedef enum
   GDK_SCROLL_SMOOTH
 } GdkScrollDirection;
 
+/**
+ * GdkScrollUnit:
+ * @GDK_SCROLL_UNIT_WHEEL: The delta is in number of wheel clicks.
+ * @GDK_SCROLL_UNIT_SURFACE: The delta is in surface pixels to scroll directly
+ *   on screen.
+ *
+ * Specifies the unit of scroll deltas.
+ *
+ * When you get %GDK_SCROLL_UNIT_WHEEL, a delta of 1.0 means 1 wheel detent
+ * click in the south direction, 2.0 means 2 wheel detent clicks in the south
+ * direction... This is the same logic for negative values but in the north
+ * direction.
+ *
+ * If you get %GDK_SCROLL_UNIT_SURFACE, are managing a scrollable view and get a
+ * value of 123, you have to scroll 123 surface logical pixels right if it's
+ * @delta_x or down if it's @delta_y. This is the same logic for negative values
+ * but you have to scroll left instead of right if it's @delta_x and up instead
+ * of down if it's @delta_y.
+ *
+ * 1 surface logical pixel is equal to 1 real screen pixel multiplied by the
+ * final scale factor of your graphical interface (the product of the desktop
+ * scale factor and eventually a custom scale factor in your app).
+ *
+ * Since: 4.8
+ */
+typedef enum
+{
+  GDK_SCROLL_UNIT_WHEEL,
+  GDK_SCROLL_UNIT_SURFACE
+} GdkScrollUnit;
+
 /**
  * GdkNotifyType:
  * @GDK_NOTIFY_ANCESTOR: the surface is entered from an ancestor or
@@ -395,6 +426,8 @@ GDK_AVAILABLE_IN_ALL
 void                    gdk_scroll_event_get_deltas     (GdkEvent *event,
                                                          double   *delta_x,
                                                          double   *delta_y);
+GDK_AVAILABLE_IN_4_8
+GdkScrollUnit           gdk_scroll_event_get_unit       (GdkEvent *event);
 
 GDK_AVAILABLE_IN_ALL
 gboolean                gdk_scroll_event_is_stop        (GdkEvent *event);
