@@ -40,9 +40,6 @@ G_BEGIN_DECLS
 #define GTK_EVENT_CONTROLLER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GTK_TYPE_EVENT_CONTROLLER, GtkEventControllerClass))
 
 
-GDK_AVAILABLE_IN_ALL
-GType               gtk_crossing_data_get_type (void) G_GNUC_CONST;
-
 
 GDK_AVAILABLE_IN_ALL
 GType        gtk_event_controller_get_type       (void) G_GNUC_CONST;
@@ -71,6 +68,9 @@ const char *        gtk_event_controller_get_name              (GtkEventControll
 GDK_AVAILABLE_IN_ALL
 void                gtk_event_controller_set_name              (GtkEventController *controller,
                                                                 const char         *name);
+GDK_AVAILABLE_IN_4_8
+void                gtk_event_controller_set_static_name       (GtkEventController *controller,
+                                                                const char         *name);
 
 GDK_AVAILABLE_IN_ALL
 GdkEvent *          gtk_event_controller_get_current_event    (GtkEventController *controller);
